aboutsummaryrefslogtreecommitdiffstats
path: root/addressbook/backend/ebook/e-card-compare.c
diff options
context:
space:
mode:
authorDan Winship <danw@src.gnome.org>2002-08-13 09:01:58 +0800
committerDan Winship <danw@src.gnome.org>2002-08-13 09:01:58 +0800
commit79a4d5a123547b18d9e513e3fb02eb4bf9999451 (patch)
treed39e75dfefd2a666e8df9239de37eb0206e53a6b /addressbook/backend/ebook/e-card-compare.c
parent0e39518ba7b473c1524e47a0b2618b503e116326 (diff)
downloadgsoc2013-evolution-79a4d5a123547b18d9e513e3fb02eb4bf9999451.tar
gsoc2013-evolution-79a4d5a123547b18d9e513e3fb02eb4bf9999451.tar.gz
gsoc2013-evolution-79a4d5a123547b18d9e513e3fb02eb4bf9999451.tar.bz2
gsoc2013-evolution-79a4d5a123547b18d9e513e3fb02eb4bf9999451.tar.lz
gsoc2013-evolution-79a4d5a123547b18d9e513e3fb02eb4bf9999451.tar.xz
gsoc2013-evolution-79a4d5a123547b18d9e513e3fb02eb4bf9999451.tar.zst
gsoc2013-evolution-79a4d5a123547b18d9e513e3fb02eb4bf9999451.zip
If invoked from a non-contact folder, add the contact to the default
* gui/component/addressbook-component.c (user_create_new_item_cb): If invoked from a non-contact folder, add the contact to the default contact folder, not the local one. If invoked from a contact folder, don't append "addressbook.db" to the URI, let ebook do the right thing. Fixes #28327 and #28325. * backend/idl/addressbook.idl (CallStatus): Add NoSuchBook. (Initially intended as part of a fix for #28327, but the other changes make it so the error code never ends up getting used any more, but it's still good to have.) * gui/widgets/e-addressbook-util.c (e_addressbook_error_dialog): Handle NO_SUCH_BOOK. * backend/ebook/e-book-types.h (EBookStatus): Add E_BOOK_STATUS_NO_SUCH_BOOK. * backend/ebook/e-book-listener.c (e_book_listener_convert_status): add case for NoSuchBook. * backend/ebook/e-book-util.c (e_book_load_local_address_book): Kill this. Nothing should ever explicitly load the local addressbook. (e_book_use_default_book): Replaces e_book_use_local_address_book, using the default book instead. (e_book_default_book_open): Fall back to local contact folder on E_BOOK_STATUS_NO_SUCH_BOOK too. (e_book_query_address_default): Use default book, not local. * gui/component/e-address-widget.c (query_idle_fn): Use the default book, not the local book. * gui/component/select-names/e-select-names-popup.c (edit_contact_info_cb): Use the default book, not the local book. * backend/ebook/e-destination.c (e_destination_cardify): Use the default book, not the local book. (e_destination_touch): Query the default book, not the local book. * backend/ebook/e-card-compare.c (e_card_locate_match, e_card_locate_match_full): Use the default book, not the local book. svn path=/trunk/; revision=17764
Diffstat (limited to 'addressbook/backend/ebook/e-card-compare.c')
-rw-r--r--addressbook/backend/ebook/e-card-compare.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/addressbook/backend/ebook/e-card-compare.c b/addressbook/backend/ebook/e-card-compare.c
index fb88603552..b8866e7e81 100644
--- a/addressbook/backend/ebook/e-card-compare.c
+++ b/addressbook/backend/ebook/e-card-compare.c
@@ -668,12 +668,12 @@ e_card_locate_match (ECard *card, ECardMatchQueryCallback cb, gpointer closure)
info->closure = closure;
info->avoid = NULL;
- e_book_use_local_address_book (use_common_book_cb, info);
+ e_book_use_default_book (use_common_book_cb, info);
}
/**
* e_card_locate_match_full:
* @book: The book to look in. If this is NULL, use the main local
* addressbook.
* @card: The card to compare to.
* @avoid: A list of cards to not match. These will not show up in the search.
@@ -701,6 +701,6 @@ e_card_locate_match_full (EBook *book, ECard *card, GList *avoid, ECardMatchQuer
if (book)
use_common_book_cb (book, info);
else
- e_book_use_local_address_book (use_common_book_cb, info);
+ e_book_use_default_book (use_common_book_cb, info);
}
@@ -668,12 +668,12 @@ e_card_locate_match (ECard *card, ECardMatchQueryCallback cb, gpointer closure)
/**
* e_card_locate_match_full:
- * @book: The book to look in. If this is NULL, use the main local
+ * @book: The book to look in. If this is NULL, use the default
* addressbook.
* @card: The card to compare to.